@@ -569,17 +569,25 @@ impl<T, const N: usize> StaticVec<T, N> {
   ///
   /// For safety reasons, as StaticVec cannot increase in capacity, the
   /// iterator is required to implement [`ExactSizeIterator`](core::iter::ExactSizeIterator)
-  /// rather than just [`Iterator`](core::iter::Iterator).
+  /// rather than just [`Iterator`](core::iter::Iterator) (though this function still does
+  /// the appropriate checking internally to avoid dangerous outcomes in the event of a blatantly
+  /// incorrect [`ExactSizeIterator`](core::iter::ExactSizeIterator) implementation.)
   #[inline]
   pub fn insert_many<I: IntoIterator<Item = T>>(&mut self, index: usize, iter: I)
   where I::IntoIter: ExactSizeIterator<Item = T> {
-    assert!(self.length < N && index <= self.length);
+    assert!(
+      self.length < N && index <= self.length,
+      "Insufficient remaining capacity / out of bounds!"
+    );
     let mut it = iter.into_iter();
     if index == self.length {
       return self.extend(it);
     }
     let iter_size = it.len();
-    assert!(index + iter_size >= index && (self.length - index) + iter_size < N);
+    assert!(
+      index + iter_size >= index && (self.length - index) + iter_size < N,
+      "Insufficient remaining capacity / out of bounds!"
+    );
     unsafe {
       let old_length = self.length;
       let mut this = self.mut_ptr_at_unchecked(index);
@@ -622,6 +630,15 @@ impl<T, const N: usize> StaticVec<T, N> {
     }
   }
 
+  /// Returns `true` if `value` is present in the StaticVec.
+  /// Locally requires that `T` implements [`PartialEq`](core::cmp::PartialEq)
+  /// to make it possible to compare the elements of the StaticVec with `value`.
+  #[inline(always)]
+  pub fn contains(&self, value: &T) -> bool
+  where T: PartialEq {
+    self.iter().any(|current| current == value)
+  }
+
   /// Removes all contents from the StaticVec and sets its length back to 0.
   #[inline(always)]
   pub fn clear(&mut self) {
@@ -870,6 +887,38 @@ impl<T, const N: usize> StaticVec<T, N> {
     res
   }
 
+  /// Returns a StaticVec containing the contents of a [`Vec`](alloc::vec::Vec) instance.
+  /// If the [`Vec`](alloc::vec::Vec) has a length greater than the declared capacity of the
+  /// resulting StaticVec, any contents after that point are ignored. Note that using this function
+  /// consumes the source [`Vec`](alloc::vec::Vec).
+  #[cfg(feature = "std")]
+  #[doc(cfg(feature = "std"))]
+  #[inline]
+  pub fn from_vec(mut vec: Vec<T>) -> Self {
+    let vec_len = vec.len();
+    let item_count = vec_len.min(N);
+    Self {
+      data: {
+        unsafe { vec.set_len(0) };
+        let mut data = Self::new_data_uninit();
+        unsafe {
+          vec
+            .as_ptr()
+            .copy_to_nonoverlapping(data.as_mut_ptr() as *mut T, item_count);
+          // Manually drop any excess values in the source vec to avoid undesirable memory leaks.
+          if vec_len > item_count {
+            ptr::drop_in_place(ptr::slice_from_raw_parts_mut(
+              vec.as_mut_ptr().add(item_count),
+              vec_len - item_count,
+            ));
+          }
+          data
+        }
+      },
+      length: item_count,
+    }
+  }
+
   /// Returns a [`Vec`](alloc::vec::Vec) containing the contents of the StaticVec instance.
   /// The returned [`Vec`](alloc::vec::Vec) will initially have the same value for
   /// [`len`](alloc::vec::Vec::len) and [`capacity`](alloc::vec::Vec::capacity) as the source
@@ -1110,6 +1159,42 @@ impl<T, const N: usize> StaticVec<T, N> {
     res
   }
 
+  /// Returns a new StaticVec representing the intersection of `self` and `other` (that is,
+  /// all items present in both `self` and `other`.)
+  ///
+  /// The `N2` parameter does not need to be provided explicitly, and can be inferred from `other`
+  /// itself.
+  ///
+  /// Locally requires that `T` implements [`Clone`](core::clone::Clone) to avoid soundness issues
+  /// while accommodating for more types than [`Copy`](core::marker::Copy) would appropriately for
+  /// this function, and [`PartialEq`](core::cmp::PartialEq) to make the item comparisons possible.
+  ///
+  /// Example usage:
+  /// ```
+  /// assert_eq!(
+  ///   staticvec![4, 5, 6, 7].intersection(&staticvec![1, 2, 3, 7, 4]),
+  ///   [4, 7],
+  /// );
+  /// ```
+  #[inline]
+  pub fn intersection<const N2: usize>(&self, other: &StaticVec<T, N2>) -> Self
+  where T: Clone + PartialEq {
+    let mut res = Self::new();
+    for left in self {
+      let mut found = false;
+      for right in other {
+        if left == right {
+          found = true;
+          break;
+        }
+      }
+      if found && !res.contains(left) {
+        unsafe { res.push_unchecked(left.clone()) }
+      }
+    }
+    res
+  }
+
   /// A concept borrowed from the widely-used `SmallVec` crate, this function
   /// returns a tuple consisting of a constant pointer to the first element of the StaticVec,
   /// the length of the StaticVec, and the capacity of the StaticVec.
