@@ -17,9 +17,6 @@
 /// ```
 #[macro_export]
 macro_rules! staticvec {
-  (@put_one $val:expr) => {
-    1
-  };
   ($val:expr; $n:expr) => {
     $crate::StaticVec::new_from_const_array([$val; $n])
   };
@@ -36,10 +33,12 @@ macro_rules! impl_extend {
     fn extend<I: IntoIterator<Item = $type>>(&mut self, iter: I) {
       let mut it = iter.into_iter();
       let mut i = self.length;
+      let mut p = unsafe { self.as_mut_ptr().add(i) };
       while i < N {
         if let Some($var_a) = it.next() {
           unsafe {
-            self.mut_ptr_at_unchecked(i).write($var_b);
+            p.write($var_b);
+            p = p.offset(1);
           }
         } else {
           break;
