@@ -328,6 +328,12 @@ fn concat_clone() {
   );
 }
 
+#[test]
+fn contains() {
+  assert_eq!(staticvec![1, 2, 3].contains(&2), true);
+  assert_eq!(staticvec![1, 2, 3].contains(&4), false);
+}
+
 #[test]
 fn dedup() {
   let mut vec = staticvec![1, 2, 2, 3, 2];
@@ -456,6 +462,26 @@ fn from() {
   );
 }
 
+#[cfg(feature = "std")]
+#[test]
+fn from_vec() {
+  let v = vec![
+    Box::new(Struct { s: "AAA" }),
+    Box::new(Struct { s: "BBB" }),
+    Box::new(Struct { s: "CCC" }),
+  ];
+  let vv = StaticVec::<Box<Struct>, 2>::from_vec(v);
+  assert_eq!(vv.capacity(), 2);
+  assert_eq!(vv.len(), 2);
+  assert_eq!(
+    vv,
+    [Box::new(Struct { s: "AAA" }), Box::new(Struct { s: "BBB" })]
+  );
+  let x = Vec::<Box<Struct>>::new();
+  let y = StaticVec::<Box<Struct>, 1>::from_vec(x);
+  assert_eq!(y, []);
+}
+
 #[test]
 fn get_unchecked() {
   let v = staticvec!["a", "b", "c"];
@@ -539,7 +565,7 @@ fn insert_many() {
 }
 
 #[test]
-#[should_panic]
+#[should_panic(expected = "Insufficient remaining capacity / out of bounds!")]
 fn insert_many_asserts() {
   let mut v: StaticVec<u8, 8> = StaticVec::new();
   for i in 0..7 {
@@ -550,6 +576,14 @@ fn insert_many_asserts() {
   v2.insert_many(27, [1, 2, 3, 4].iter().cloned());
 }
 
+#[test]
+fn intersection() {
+  assert_eq!(
+    staticvec![4, 5, 6, 7].intersection(&staticvec![1, 2, 3, 7, 4]),
+    [4, 7],
+  );
+}
+
 #[test]
 fn is_empty() {
   let mut v = StaticVec::<i32, 1>::new();
